==> ovirt-engine-3.5.6.2.tar.gz: backend/manager/modules/vdsbroker/src/main/java/org/ovirt/engine/core/vdsbroker/vdsbroker/VMListReturnForXmlRpc.java <==
package org.ovirt.engine.core.vdsbroker.vdsbroker;

import java.util.HashMap;
import java.util.Map;

//-----------------------------------------------------
//
//-----------------------------------------------------

//-----------------------------------------------------
//
//-----------------------------------------------------
@SuppressWarnings("unchecked")
public final class VMListReturnForXmlRpc {

    private static final String STATUS = "status";
    private static final String VM_LIST = "vmList";
    private static final Map<String, Object>[] EMPTY_ARRAY_OF_MAPS = new HashMap[0];

    public StatusForXmlRpc mStatus;
    public Map<String, Object>[] mVmList = EMPTY_ARRAY_OF_MAPS;

    public VMListReturnForXmlRpc(Map<String, Object> innerMap) {
        mStatus = new StatusForXmlRpc((Map<String, Object>) innerMap.get(STATUS));
        Object[] temp = (Object[]) innerMap.get(VM_LIST);
        if (temp != null) {
            mVmList = new HashMap[temp.length];
            for (int i = 0; i < temp.length; i++) {
                // 1196327: we need to process both types of list message
                // when temp[i] is a String we process array of vmids
                // when temp[i] is a Map we process a map with status to vmid mapping
                if (String.class.isInstance(temp[i])) {
                    Map<String, Object> map = new HashMap<>();
                    map.put("vmId", temp[i]);
                    mVmList[i] = map;
                } else {
                    mVmList[i] = (Map<String, Object>) temp[i];
                }
            }
        }
    }

}

==> ovirt-engine-4.0.6.tar.gz: backend/manager/modules/vdsbroker/src/main/java/org/ovirt/engine/core/vdsbroker/vdsbroker/VMListReturnForXmlRpc.java <==
package org.ovirt.engine.core.vdsbroker.vdsbroker;

import java.util.HashMap;
import java.util.Map;

//-----------------------------------------------------
//
//-----------------------------------------------------

//-----------------------------------------------------
//
//-----------------------------------------------------
@SuppressWarnings("unchecked")
public final class VMListReturnForXmlRpc {

    private static final String STATUS = "status";
    private static final String VM_LIST = "vmList";
    private static final Map<String, Object>[] EMPTY_ARRAY_OF_MAPS = new HashMap[0];

    public StatusForXmlRpc status;
    public Map<String, Object>[] vmList = EMPTY_ARRAY_OF_MAPS;

    public VMListReturnForXmlRpc(Map<String, Object> innerMap) {
        status = new StatusForXmlRpc((Map<String, Object>) innerMap.get(STATUS));
        Object[] temp = (Object[]) innerMap.get(VM_LIST);
        if (temp != null) {
            vmList = new HashMap[temp.length];
            for (int i = 0; i < temp.length; i++) {
                // 1196327: we need to process both types of list message
                // when temp[i] is a String we process array of vmids
                // when temp[i] is a Map we process a map with status to vmid mapping
                if (String.class.isInstance(temp[i])) {
                    Map<String, Object> map = new HashMap<>();
                    map.put("vmId", temp[i]);
                    vmList[i] = map;
                } else {
                    vmList[i] = (Map<String, Object>) temp[i];
                }
            }
        }
    }

}
